package writer2latex.xhtml;

import java.util.LinkedList;

import javax.swing.text.Element;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import writer2latex.office.XMLString;
import writer2latex.util.Misc;


//LinkedList<String>   stringList = new LinkedList<String>();
public class GreenstoneTags {

	private static LinkedList<Integer> headerStack = new LinkedList<Integer>();
	private static boolean pageSection = false; 
	private static String tagsType = "none";

	protected static void processHeading(Node currentNode, Node hnode, int pageNum) {
		
		if (tagsType.equals("none") || tagsType.equals("pages")){
			return;
		}
		
		String sLevel = Misc.getAttribute(currentNode, XMLString.TEXT_OUTLINE_LEVEL);
		//If this heading contain outline-level
		if (sLevel != null && !sLevel.isEmpty()) {
			int nLevel = Integer.parseInt(sLevel);
			// Close page section if opened
			if (pageSection) {
				closeSection(hnode);
				pageSection = false;
			}
			
			closeHeadingSections(hnode, nLevel);
			Node nextNode = currentNode.getNextSibling();
			//Useless to open section if we are at end of the document
			if (nextNode != null){
				String title = getTitle(currentNode); 
				//Open Heading section
				openSection(hnode, title);
				headerStack.offerFirst(Integer.parseInt(sLevel));
				//If next node is not a heading element with outline number and tags type is headings-pages 
				//Then open paged section
				if (!(
					nextNode.getNodeType() == Node.ELEMENT_NODE 
					&& nextNode.getNodeName().equals(XMLString.TEXT_H)
					&& Misc.getAttribute(nextNode, XMLString.TEXT_OUTLINE_LEVEL) != null
					&& !Misc.getAttribute(nextNode, XMLString.TEXT_OUTLINE_LEVEL).isEmpty()
					)
					&& tagsType.equals("headings-pages")
					) {
						//Open page section 
						openSection(hnode, pageNum);
				}
			}	
				
		}
		return;
	}
	protected static void processPageBreak(Node currentNode, Node hnode, Integer pageNum){
		
		if (tagsType.equals("none") || tagsType.equals("headings")){
			return;
		}
		
		if ( !( currentNode.getNodeType() == Node.ELEMENT_NODE 
				&& currentNode.getNodeName().equals(XMLString.TEXT_H)
				&& Misc.getAttribute(currentNode, XMLString.TEXT_OUTLINE_LEVEL) != null
				&& !Misc.getAttribute(currentNode, XMLString.TEXT_OUTLINE_LEVEL).isEmpty()
				)
				&& !headerStack.isEmpty()
				|| tagsType.equals("pages")
				) {
			if (pageSection) {
				closeSection(hnode);
				pageSection = false;

			}
			if (pageNum != null) {
				openSection(hnode, pageNum);
				
			}
		}
	}
	//Method to open main document tag
	protected static void StartDocument(Node hnode, String title, String type, int pageNum){
		tagsType = type;
		if (tagsType.equals("none")){
			return;
		}
		//Create main document section
		openSection(hnode, title);
		if (tagsType.equals("pages")){
			//Open page section
			openSection(hnode, pageNum);
		}
		
		
	}
	//Method to close open tags at the end of the document
	protected static void endDocument(Node hnode){
		if (tagsType.equals("none")){
			return;
		}
		if (pageSection){
			closeSection(hnode);
			pageSection = false;
		}
		closeSection(hnode);
		//Clean stack, close all sections
		closeHeadingSections(hnode, 0);
	}
	
	private static String getTitle(Node currentNode) {
		Node content = currentNode.cloneNode(true);
		NodeList contentNodes = content.getChildNodes();
		String title = null;

		int i = 0;
		while (i < contentNodes.getLength()) {
			Node child = contentNodes.item(i);
			if (child.getNodeType() == Node.ELEMENT_NODE){
				if (child.getNodeName().equals(XMLString.TEXT_TAB) ||
					child.getNodeName().equals(XMLString.TEXT_LINE_BREAK)	){
					Document doc = child.getOwnerDocument();
					Node testSpace = doc.createTextNode(" ");
					content.insertBefore(testSpace, child);
					content.removeChild(child);
				}
			}
				i++;
		} 
		
		title = content.getTextContent();
		
		return title;
	}

	
	private static void openSection(Node hnode, Integer pageNum){
		Document doc = hnode.getOwnerDocument();
		String commentText = "<Section>\n<Description>\n<Metadata name=\"Title\">" + pageNum
				+ "</Metadata>\n<Metadata name=\"Page\">" + pageNum + "</Metadata>\n</Description>";
		Node openSection = doc.createComment(commentText);
		// insert open section comment before header node
		hnode.appendChild(openSection);
		pageSection = true;
	}
	private static void openSection(Node hnode, String title){
		Document doc = hnode.getOwnerDocument();
		String commentText = "<Section>\n<Description>\n<Metadata name=\"Title\">" + title
				+ "</Metadata>\n</Description>";
		Node openSection = doc.createComment(commentText);
		// insert open section comment before header node
		hnode.appendChild(openSection);
	}

	private static void closeSection(Node hnode){
		Document doc = hnode.getOwnerDocument();
		String commentText = "</Section>";
		Node closeSection = doc.createComment(commentText);
		//insert open section comment before header node
		hnode.appendChild(closeSection);
	}
	
	private static void closeHeadingSections(Node hnode, int nLevel){
		if (headerStack.isEmpty()) {
			return;
		}
		//Close all sections with level less than current
		while (nLevel <= headerStack.peek()) {
			closeSection(hnode);
			headerStack.poll();
			if (headerStack.isEmpty()) {
				break;
			}

		}

	}
}
	